@@ -1,12 +1,11 @@
-
 require 'erb'
 
 module Commander
   module HelpFormatter
     class TerminalCompact < Terminal
-      def template name
+      def template(name)
         ERB.new(File.read(File.join(File.dirname(__FILE__), 'terminal_compact', "#{name}.erb")), nil, '-')
       end
     end
   end
-end
\ No newline at end of file
+end
