@@ -4,8 +4,8 @@ module Commander
     include Commander::UI::AskForClass
     include Commander::Delegates
 
-    if $stdin.tty? && (cols = $terminal.output_cols) >= 40
-      $terminal.wrap_at = cols - 5
+    if $stdin.tty? && (cols = HighLine.default_instance.output_cols) >= 40
+      HighLine.default_instance.wrap_at = cols - 5
     end
   end
 end
